==> request-tracker4_4.4.7+dfsg.orig-third-party-source.tar.gz: rt-4.4.7/devel/third-party/ckeditor-src/plugins/link/lang/ca.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'ca', {
	acccessKey: 'Clau d\'accés',
	advanced: 'Avançat',
	advisoryContentType: 'Tipus de contingut consultiu',
	advisoryTitle: 'Títol consultiu',
	anchor: {
		toolbar: 'Insereix/Edita àncora',
		menu: 'Propietats de l\'àncora',
		title: 'Propietats de l\'àncora',
		name: 'Nom de l\'àncora',
		errorName: 'Si us plau, escriviu el nom de l\'ancora',
		remove: 'Remove Anchor'
	},
	anchorId: 'Per Id d\'element',
	anchorName: 'Per nom d\'àncora',
	charset: 'Conjunt de caràcters font enllaçat',
	cssClasses: 'Classes del full d\'estil',
	emailAddress: 'Adreça de correu electrònic',
	emailBody: 'Cos del missatge',
	emailSubject: 'Assumpte del missatge',
	id: 'Id',
	info: 'Informació de l\'enllaç',
	langCode: 'Direcció de l\'idioma',
	langDir: 'Direcció de l\'idioma',
	langDirLTR: 'D\'esquerra a dreta (LTR)',
	langDirRTL: 'De dreta a esquerra (RTL)',
	menu: 'Edita l\'enllaç',
	name: 'Nom',
	noAnchors: '(No hi ha àncores disponibles en aquest document)',
	noEmail: 'Si us plau, escrigui l\'adreça correu electrònic',
	noUrl: 'Si us plau, escrigui l\'enllaç URL',
	other: '<altre>',
	popupDependent: 'Depenent (Netscape)',
	popupFeatures: 'Característiques finestra popup',
	popupFullScreen: 'Pantalla completa (IE)',
	popupLeft: 'Posició esquerra',
	popupLocationBar: 'Barra d\'adreça',
	popupMenuBar: 'Barra de menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barres d\'scroll',
	popupStatusBar: 'Barra d\'estat',
	popupToolbar: 'Barra d\'eines',
	popupTop: 'Posició dalt',
	rel: 'Relació',
	selectAnchor: 'Selecciona una àncora',
	styles: 'Estil',
	tabIndex: 'Index de Tab',
	target: 'Destí',
	targetFrame: '<marc>',
	targetFrameName: 'Nom del marc de destí',
	targetPopup: '<finestra emergent>',
	targetPopupName: 'Nom finestra popup',
	title: 'Enllaç',
	toAnchor: 'Àncora en aquesta pàgina',
	toEmail: 'Correu electrònic',
	toUrl: 'URL',
	toolbar: 'Insereix/Edita enllaç',
	type: 'Tipus d\'enllaç',
	unlink: 'Elimina l\'enllaç',
	upload: 'Puja'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/link/lang/ca.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'ca', {
	acccessKey: 'Clau d\'accés',
	advanced: 'Avançat',
	advisoryContentType: 'Tipus de contingut consultiu',
	advisoryTitle: 'Títol consultiu',
	anchor: {
		toolbar: 'Insereix/Edita àncora',
		menu: 'Propietats de l\'àncora',
		title: 'Propietats de l\'àncora',
		name: 'Nom de l\'àncora',
		errorName: 'Si us plau, escriviu el nom de l\'ancora',
		remove: 'Remove Anchor'
	},
	anchorId: 'Per Id d\'element',
	anchorName: 'Per nom d\'àncora',
	charset: 'Conjunt de caràcters font enllaçat',
	cssClasses: 'Classes del full d\'estil',
	download: 'Force Download', // MISSING
	displayText: 'Text a mostrar',
	emailAddress: 'Adreça de correu electrònic',
	emailBody: 'Cos del missatge',
	emailSubject: 'Assumpte del missatge',
	id: 'Id',
	info: 'Informació de l\'enllaç',
	langCode: 'Direcció de l\'idioma',
	langDir: 'Direcció de l\'idioma',
	langDirLTR: 'D\'esquerra a dreta (LTR)',
	langDirRTL: 'De dreta a esquerra (RTL)',
	menu: 'Edita l\'enllaç',
	name: 'Nom',
	noAnchors: '(No hi ha àncores disponibles en aquest document)',
	noEmail: 'Si us plau, escrigui l\'adreça correu electrònic',
	noUrl: 'Si us plau, escrigui l\'enllaç URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<altre>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Depenent (Netscape)',
	popupFeatures: 'Característiques finestra popup',
	popupFullScreen: 'Pantalla completa (IE)',
	popupLeft: 'Posició esquerra',
	popupLocationBar: 'Barra d\'adreça',
	popupMenuBar: 'Barra de menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barres d\'scroll',
	popupStatusBar: 'Barra d\'estat',
	popupToolbar: 'Barra d\'eines',
	popupTop: 'Posició dalt',
	rel: 'Relació',
	selectAnchor: 'Selecciona una àncora',
	styles: 'Estil',
	tabIndex: 'Index de Tab',
	target: 'Destí',
	targetFrame: '<marc>',
	targetFrameName: 'Nom del marc de destí',
	targetPopup: '<finestra emergent>',
	targetPopupName: 'Nom finestra popup',
	title: 'Enllaç',
	toAnchor: 'Àncora en aquesta pàgina',
	toEmail: 'Correu electrònic',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Insereix/Edita enllaç',
	type: 'Tipus d\'enllaç',
	unlink: 'Elimina l\'enllaç',
	upload: 'Puja'
} );
